@@ -75,7 +75,7 @@ def get_args():
     version = parser.add_argument_group(title='Version')
     version.add_argument('--version', action="version",
                         help='Print version and exit.',
-                        version='BacGenomePipeline {}'.format('1.0.5'))
+                        version='BacGenomePipeline {}'.format('1.0.7'))
 
 
     pipeline_mode = parser.add_mutually_exclusive_group(required=True)
@@ -120,11 +120,13 @@ def get_args():
     pipeline_options.add_argument('-s', '--asm_fasta',
                                   help='Add Genome assembly in fasta format',
                                   default=None,
-                                  type=fasta_file_validation)
+                                  type=fasta_file_validation,
+                                  metavar='')
     pipeline_options.add_argument('-w', '--q_weight',
                                   help='Add mean_q_weight for read filtering',
                                   default=7,
-                                  type=int)
+                                  type=int,
+                                  metavar='')
 
 
 
